#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Lloyd Carothers
ms_sum
prints a sync like output ignoring all gaps
"""

import os
import sys
from obspy.io.mseed.core import _is_mseed
from obspy.io.mseed import util

from nexus.obspy_improved import InventoryIm


def main():
    """
    Main function to process MiniSEED files and directories.

    This function creates an InventoryIm object and processes each path
    provided as a command-line argument. If the path is a file and is a
    MiniSEED file, it reads the record information and end time, then adds
    the record information to the inventory. If the path is a directory, it
    scans the directory for MiniSEED files and adds them to the inventory.

    Finally, it prints a summary of the inventory.
    """
    inv = InventoryIm()
    for path in sys.argv[1:]:
        if os.path.isfile(path) and _is_mseed(path):
            with open(path, 'rb') as fp:
                rec = util.get_record_information(fp)
                endtime = util.get_start_and_end_time(fp)
            rec['endtime'] = endtime[1]
            inv.add_from_record_info(rec)
        elif os.path.isdir(path):
            inv.scan_quick(path,log_message=lambda x:None)
    inv.print_sum()
